__version__ = "1.6"
import os
from . import check

check.check_os()
# Checking if required files exists or not
check.check_json()
check.app_names()

# Get the path of working directory
main_path = os.path.join((check.get_path()), "Data")

# Run application (Regex implemented)
def run(self, output=True):
    print()
    print("THIS IS THE BETA VERSION (FOR JUST CHECKING METHOD OF CREATION OF FILES)")
    print()




def commands():
    data = [['KEY', 'USE'],
            ['(?)','DOCUMENTATION'],
            ['(VERSION)','SEE APPOPENER VERSION'],
            ['(LS)','LIST OF APPLICATIONS'],
            ['(FIND XYZ)', "FIND APPLICATION"],
            ['(UPDATE -M)','UPDATE APPNAMES MANUALLY'],
            ['(UPDATE)','LOAD NEW DATA'],
            ['(OLD > NEW)','UPDATE APP VIA CLI'],
            ['(DEFAULT)','RESTORES DEFAULT APPNAMES'],
            ['(LOG)','SEE CHANGED PETNAME(s)'],
            ['(CLS)','CLEARS SCREEN'],
            ['(Q)','EXIT PROGRAM']
            ]
    dash = '-' * 35
    for i in range(len(data)):
        if i == 0:
            print(dash)
            print('{:<15s}{:^15s}'.format(data[i][0],data[i][1]))
            print(dash)
        else:
            print('{:<15s}{:^12s}'.format(data[i][0],data[i][1]))


import subprocess
import json

import os

def get_powershell_path():
    try:
        # Default installation directories for PowerShell
        installation_directories = [
            r"C:\Windows\System32\WindowsPowerShell\v1.0\powershell.exe",
            r"C:\Windows\SysWOW64\WindowsPowerShell\v1.0\powershell.exe"
        ]

        # Check if the PowerShell executable exists in the default directories
        for path in installation_directories:
            if os.path.isfile(path):
                return path

        return None
    except Exception as e:
        print("Error occurred:", e)

# Call the function to get the PowerShell executable location
powershell_path = get_powershell_path()

print("PowerShell executable path:", powershell_path)

def old_skool():
    # Run the PowerShell command
    powershell_command = "Get-StartApps | ConvertTo-Json"
    process = subprocess.Popen([powershell_path, "-Command", powershell_command], stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True, encoding="utf-8")
    output, error = process.communicate()

    # Check for any errors
    if error:
        print("Error:", error)

    # Parse the output as JSON
    parsed_output = json.loads(output)
    return parsed_output